# My school task:

```
Wydaje swoją aplikację z zajęć (ta, do której pisaliśmy testy etc.) do testowego rejestru paczek: https://test.pypi.org

Podobnie do mojego repo: https://github.com/VerticalHeretic/Teilnahme
```